Contributing Guidelines
=======================

Contributions to the project are welcome. Please refer to the
`CONTRIBUTING.md <contributing>`_ file for more detailed information on the
various ways you can contribute.

.. _contributing: https://code.usgs.gov/water/computational-tools/surface-water-work/hyswap/-/blob/main/CONTRIBUTING.md
